<?php

/**
 * @file
 * Contains \Drupal\visually_impaired_module\Form\VISettingsForm.
 */

namespace Drupal\visually_impaired_module\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form that configures forms module settings.
 */
class VISettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'visually_impaired_module_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'visually_impaired_module.visually_impaired_module.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('visually_impaired_module.visually_impaired_module.settings');
    $theme_handler = \Drupal::service('theme_handler');
    $themes = array();
    $options = $theme_handler->listInfo();
    foreach ($options as $name => $attr) {
      if ($attr->status) {
        $themes[$name] = $attr->info['name'];
      }
    }
    $form['default_visually_impaired_theme'] = array(
      '#type' => 'select',
      '#title' => $this->t('Select Visually Impaired Theme'),
      '#options' => $themes,
      '#default_value' => $config->get('visually_impaired_theme'),
    );
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->config('visually_impaired_module.visually_impaired_module.settings')
      ->set('visually_impaired_theme', $values['default_visually_impaired_theme'])
      ->save();
  }
}
